From e52d685312e81a908837c0ef82c9283573d07d83 Mon Sep 17 00:00:00 2001
From: Olivier Sauter <olivier.sauter@epfl.ch>
Date: Wed, 19 Mar 2003 16:11:06 +0000
Subject: [PATCH] add zmageff

git-svn-id: https://spcsvn.epfl.ch/repos/TCV/gdat/trunk@1889 d63d8f72-b253-0410-a779-e742ad2e26cf
---
 JET/Ra_rho_t.m | 16 ++++++++++------
 1 file changed, 10 insertions(+), 6 deletions(-)

diff --git a/JET/Ra_rho_t.m b/JET/Ra_rho_t.m
index f7110235..83c9fc9b 100644
--- a/JET/Ra_rho_t.m
+++ b/JET/Ra_rho_t.m
@@ -1,10 +1,12 @@
-function [R0zmag,azmag,Rminzmag,Rmaxzmag]=Ra_rho_t(sspr,sspi,npts);
+function [R0zmag,azmag,Rminzmag,Rmaxzmag,zmageff]=Ra_rho_t(sspr,sspi,npts);
+%
+% function [R0zmag,azmag,Rminzmag,Rmaxzmag,zmageff]=Ra_rho_t(sspr,sspi,npts);
 %
 % Rmax(psi^.5),Rmin(psi^.5) and a(psi^.5) on z=zmag on npts equidistant sqrt(psin)
 %
 % Assumes all timing the same: sspr.t, sspi.t, zmag.t, rmag.t
 %
 % cannot use zmag as not good enough with respect to psirz. Better to use min of psirz contours
 %
 % precision within 1e-3 - 1e-4 (as usually min(psi)~a few 1e-4)
 %
@@ -28,11 +30,12 @@ Rminzmag=azmag;
 Rminzmag.name='Rmin(rho,t)=Rbnd_HFS from psi(R,Z) and Ra_rho_t function';
 Rmaxzmag=azmag;
 Rmaxzmag.name='a(rho,t)=Rbnd_LFS from psi(R,Z) and Ra_rho_t function';
+zmageff=NaN*ones(size(sspr.t));
 
-iteff=find(sspr.t>=54 & sspr.t<=69);
-% for it=1:length(sspr.t)
-for it1=1:length(iteff)
-  it=iteff(it1);
+% iteff=find(sspr.t>=54 & sspr.t<=69);
+for it=1:length(sspr.t)
+%for it1=1:length(iteff)
+%  it=iteff(it1);
   [r,z,psinrz]=psinrzjet(-1,sspr.t(it),3*npts,3*npts,[],[],[],0,sspr,sspi,[]);
   ir=find(r>2.7 & r<3.3);
   iz=find(z>-1 & z<1.5);
@@ -63,6 +66,7 @@ for it1=1:length(iteff)
   R0zmag.data(1,it)=rmagmin;
   Rminzmag.data(:,it)=RpsiHFS;
   Rmaxzmag.data(:,it)=RpsiLFS;
+  zmageff(it)=zeff;
   % get isoflux
   %  [c1,h1]=contour(r,z,psinrz',rhopsi.^2);
   %  for ir=1:length(rhopsi)
@@ -1,10 +1,12 @@
 % Assumes all timing the same: sspr.t, sspi.t, zmag.t, rmag.t
 %
-% cannot use zmag as not good enough with respect to psirz. Better to use min of psirz contours
+% cannot use zmag as not good enough with respect to psirz. Better to use min of psirz contours, zmageff
 %
 % precision within 1e-3 - 1e-4 (as usually min(psi)~a few 1e-4)
-- 
GitLab